<template>
  <div class="dashboard-container">
    <el-row :gutter="40" class="panel-group">
      <el-col :xs="12" :sm="12" :lg="6" class="card-panel-col" >
        <div class="card-panel">
          <el-row class="panel-group" :gutter="20">
            <div class="card-panel-icon-wrapper icon-people">
              <svg-icon icon-class="list" class-name="card-panel-icon"/>
            </div>
            <div class="card-panel-description">
              <div class="card-panel-text">
                <p>考试列表</p>
              </div>
            </div>
          </el-row>
          <el-row class="panel-group">
            <el-input v-model="query.examName" placeholder="请输入考试名称" style="width: 70%;margin-bottom: 10px;margin-left: 10px;" size="small" @input="getExamList"/>
            <el-button type="primary" size="small" @click="getExamList">查询</el-button>
          </el-row>
          <el-row class="panel-group">
            <el-table :data="examList" style="width: 100%;" height="430" @row-click="handleRowClick">
              <el-table-column label="考试名称" prop="examName"></el-table-column>
              <el-table-column label="考试状态" prop="status"></el-table-column>
            </el-table>
          </el-row>
        </div>
      </el-col>
      <el-col :span="18">
        <el-row>
          <el-col :xs="12" :sm="12" :lg="6" class="card-panel-col">
            <div class="nameClass">
              <p class="examInfo-text">当前考试：{{examInfo.currentExamName}}</p>
            </div>
          </el-col>
          <el-col :xs="12" :sm="12" :lg="5" class="card-panel-col">
            <div class="nameClass">
              <p class="examInfo-text">应考人数：{{examInfo.toUserCount}}</p>
            </div>
          </el-col>
          <el-col :xs="12" :sm="12" :lg="5" class="card-panel-col">
            <div class="nameClass">
              <p class="examInfo-text">缺考人数：{{examInfo.missUserCount}}</p>
            </div>
          </el-col>
          <el-col :xs="12" :sm="12" :lg="4" class="card-panel-col">
            <div class="nameClass">
              <p class="examInfo-text">最高分：{{examInfo.maxScore}}</p>
            </div>
          </el-col>
          <el-col :xs="12" :sm="12" :lg="4" class="card-panel-col">
            <div class="nameClass">
              <p class="examInfo-text">最低分：{{examInfo.minScore}}</p>
            </div>
          </el-col>
        </el-row>
        <el-row>

        </el-row>
      </el-col>
    </el-row>
    <el-row class="echarts-line">
      <div id="echarts-moth-user" style="width: 100%;height:400px;" v-loading="loading"/>
    </el-row>
    <el-row class="echarts-line">
      <div id="echarts-moth-question" style="width: 100%;height:400px;" v-loading="loading"/>
    </el-row>
  </div>
</template>

<script>
import resize from './components/mixins/resize'
import CountTo from 'vue-count-to'
import dashboardApi from '@/api/dashboard'
import {getExamList} from "@/api/exam"
import exam from "@/store/modules/exam"
import examPaperAnswerApi from '@/api/examPaperAnswer'


export default {
  mixins: [resize],
  components: {
    CountTo
  },
  data () {
    return {
      // 考试列表
      examList: [],
      // 考试查询条件
      query:{
        examName: '',
      },
      examInfo:{
        // 考试名称
        currentExamName: '',
        // 应到人数
        toUserCount: 0,
        // 缺考人数
        missUserCount: 0,
        // 最高分
        maxScore: 0,
        // 最低分
        minScore: 0,
      },
      examPaperCount: 0,
      questionCount: 0,
      doExamPaperCount: 0,
      doQuestionCount: 0,
      echartsUserAction: null,
      echartsQuestion: null,
      loading: false
    }
  },
  mounted () {
    // eslint-disable-next-line no-undef
    this.echartsUserAction = echarts.init(document.getElementById('echarts-moth-user'), 'macarons')
    // eslint-disable-next-line no-undef
    this.echartsQuestion = echarts.init(document.getElementById('echarts-moth-question'), 'macarons')
    let _this = this
    this.loading = true
    dashboardApi.index().then(re => {
      let response = re.data
      _this.examPaperCount = response.examPaperCount
      _this.questionCount = response.questionCount
      _this.doExamPaperCount = response.doExamPaperCount
      _this.doQuestionCount = response.doQuestionCount
      _this.echartsUserAction.setOption(this.option('用户活跃度', '{b}日{c}度', response.mothDayText, response.mothDayUserActionValue))
      _this.echartsQuestion.setOption(this.option('题目月数量', '{b}日{c}题', response.mothDayText, response.mothDayDoExamQuestionValue))
      this.loading = false
    })
  },
  methods: {
    // 获取考试列表
    getExamList() {
      let _this = this
      getExamList(this.query).then(res => {
        let response = res.data
        _this.examList = response.data
      })
    },
    // 点击考试列表更新考试数据
    handleRowClick(row){
      // 清空旧的考试数据
      this.examInfo = {
        // 考试名称
        currentExamName: '',
          // 应到人数
          toUserCount: 0,
          // 缺考人数
          missUserCount: 0,
          // 最高分
          maxScore: 0,
          // 最低分
          minScore: 0,
      }
      // 获取当前考试名称
      this.examInfo.currentExamName = row.examName
      // 获取应到实到人数
      examPaperAnswerApi.pageExamPaper({examId: row.id, pageIndex: 1, pageSize: 10}).then(res => {
        let response = res.data.list[0]
        this.examInfo.toUserCount = response.personTotalNum
        this.examInfo.missUserCount = this.examInfo.toUserCount - response.personAnswerNum
      })
      // 获取本场考试的最高分和最低分
      examPaperAnswerApi.queryMaxAndMinScore(row.id).then(res => {
        let data = res.data
        if (!data || data.length === 0) {
          this.examInfo.maxScore = 0
          this.examInfo.minScore = 0
        }else {
          this.examInfo.maxScore = data[0].totalScore
          this.examInfo.minScore = data[1].totalScore
        }
      })
    },
    option (title, formatter, label, vaule) {
      return {
        title: {
          text: title,
          x: 'center'
        },
        tooltip: {
          trigger: 'item',
          formatter: formatter
        },
        xAxis: {
          type: 'category',
          data: label
        },
        grid: {
          left: 10,
          right: 10,
          bottom: 20,
          top: 30,
          containLabel: true
        },
        yAxis: {
          type: 'value'
        },
        series: [{
          data: vaule,
          type: 'line'
        }]
      }
    }
  },
  created() {
    this.getExamList()
  }
}
</script>

<style lang="scss" scoped>

.dashboard-container {
  padding: 32px;
  background-color: rgb(240, 242, 245);
  position: relative;

  .chart-wrapper {
    background: #fff;
    padding: 16px 16px 0;
    margin-bottom: 32px;
  }
}

@media (max-width: 1024px) {
  .chart-wrapper {
    padding: 8px;
  }
}

.dashboard-editor-container {
  padding: 32px;
  background-color: rgb(240, 242, 245);
  position: relative;

  .github-corner {
    position: absolute;
    top: 0px;
    border: 0;
    right: 0;
  }

  .chart-wrapper {
    background: #fff;
    padding: 16px 16px 0;
    margin-bottom: 32px;
  }
}

@media (max-width: 1024px) {
  .chart-wrapper {
    padding: 8px;
  }
}

.panel-group {
  margin-top: 0px;

  .card-panel-col {
    padding: 10px;
    margin-bottom: 32px;
  }

  .card-panel2 {
    height: 100px;
    width: 100%;
    cursor: pointer;
    font-size: 12px;
    position: relative;
    overflow: hidden;
    color: #666;
    background: #fff;
    box-shadow: 4px 4px 40px rgba(0, 0, 0, .05);
    border-color: rgba(0, 0, 0, .05);
  }

  .card-panel {
    height: 600px;
    cursor: pointer;
    font-size: 12px;
    position: relative;
    overflow: hidden;
    color: #666;
    background: #fff;
    box-shadow: 4px 4px 40px rgba(0, 0, 0, .05);
    border-color: rgba(0, 0, 0, .05);

    &:hover {
      .card-panel-icon-wrapper {
        color: #fff;
      }

      .icon-people {
        background: #40c9c6;
      }

      .icon-message {
        background: #36a3f7;
      }

      .icon-money {
        background: #f4516c;
      }

      .icon-shopping {
        background: #34bfa3
      }
    }

    .icon-people {
      color: #40c9c6;
    }

    .icon-message {
      color: #36a3f7;
    }

    .icon-money {
      color: #f4516c;
    }

    .icon-shopping {
      color: #34bfa3
    }

    .card-panel-icon-wrapper {
      float: left;
      margin: 14px 0 0 14px;
      padding: 16px;
      transition: all 0.38s ease-out;
      border-radius: 6px;
    }

    .card-panel-icon {
      float: left;
      font-size: 48px;
    }

    .card-panel-description {
      float: right;
      font-weight: bold;
      margin: 26px;
      margin-left: 0px;

      .card-panel-text {
        line-height: 18px;
        color: rgba(0, 0, 0, 0.45);
        font-size: 16px;
        margin-bottom: 12px;
      }

      .card-panel-num {
        font-size: 20px;
      }
    }
  }
}

@media (max-width: 550px) {
  .card-panel-description {
    display: none;
  }

  .card-panel-icon-wrapper {
    float: none !important;
    width: 100%;
    height: 100%;
    margin: 0 !important;

    .svg-icon {
      display: block;
      margin: 14px auto !important;
      float: none !important;
    }
  }
}

.echarts-line{
  background:#fff;
  padding:16px 16px 0;
  margin-bottom:32px;
}

.examInfo-text {
  line-height: 18px;
  color: rgba(0, 0, 0, 0.45);
  font-size: 16px;
  margin-bottom: 12px;
}

.nameClass {
  width: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
  height: 70px;
  background-color: white;
}
</style>
